==> sdk-3.1.0-sources.jar: com/kontakt/sdk/android/ble/cache/EddystoneCacheResolveStrategy.java <==
package com.kontakt.sdk.android.ble.cache;

import com.kontakt.sdk.android.common.model.EddystoneFutureUID;
import com.kontakt.sdk.android.common.model.EddystoneUid;
import com.kontakt.sdk.android.common.model.ResolvedId;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

class EddystoneCacheResolveStrategy implements EddystoneResolveStrategy {

  private final FutureShufflesCache cache;

  EddystoneCacheResolveStrategy(FutureShufflesCache cache) {
    this.cache = cache;
  }

  @Override public List<EddystoneFutureUID> resolve(Map<EddystoneUid, EddystoneResolveRequest> requests) throws Exception {
    List<EddystoneUid> toResolve = eddystonesToResolve(requests);
    if (toResolve.isEmpty()) {
      return Collections.emptyList();
    }

    List<EddystoneFutureUID> futureIds = resolveEddystones(toResolve);
    updateRequests(requests, futureIds);
    return futureIds;
  }

  private List<EddystoneUid> eddystonesToResolve(final Map<EddystoneUid, EddystoneResolveRequest> requests) {
    List<EddystoneUid> toResolve = new ArrayList<>();
    for (Map.Entry<EddystoneUid, EddystoneResolveRequest> entry : requests.entrySet()) {
      EddystoneResolveRequest request = entry.getValue();
      if (ResolveRequestStatus.RESOLVED == request.getStatus()) {
        continue;
      }
      toResolve.add(entry.getKey());
    }
    return toResolve;
  }

  private List<EddystoneFutureUID> resolveEddystones(List<EddystoneUid> uids) {
    List<EddystoneFutureUID> futureIds = new ArrayList<>();
    for (EddystoneUid eddystoneUID : uids) {
      ResolvedId resolvedId = cache.get(eddystoneUID.toString());
      if (resolvedId == null || FutureShufflesCache.PHANTOM_ENTRY.equals(resolvedId)) {
        continue;
      }

      EddystoneFutureUID eddystoneFutureId = new EddystoneFutureUID.Builder()
          .futureIds(new ArrayList<EddystoneUid>())
          .uniqueId(resolvedId.getUniqueId())
          .queriedBy(eddystoneUID)
          .resolved(resolvedId.getEddystoneUID())
          .build();
      futureIds.add(eddystoneFutureId);
    }
    return futureIds;
  }

  private void updateRequests(Map<EddystoneUid, EddystoneResolveRequest> requests, List<EddystoneFutureUID> futureIds) {
    for (EddystoneFutureUID id : futureIds) {
      updateRequest(requests, id);
    }
  }

  private void updateRequest(Map<EddystoneUid, EddystoneResolveRequest> requests, EddystoneFutureUID id) {
    EddystoneResolveRequest request = requests.get(id.getQueriedBy());
    request.setResolvedBy(ResolverType.CACHE);
    if (ResolveRequestStatus.IGNORED == request.getStatus()) {
      return;
    }
    request.setStatus(ResolveRequestStatus.RESOLVED);
  }
}

==> sdk-3.2.2-sources.jar: com/kontakt/sdk/android/ble/cache/EddystoneCacheResolveStrategy.java <==
package com.kontakt.sdk.android.ble.cache;

import com.kontakt.sdk.android.common.model.EddystoneFutureUID;
import com.kontakt.sdk.android.common.model.EddystoneUid;
import com.kontakt.sdk.android.common.model.ResolvedId;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

class EddystoneCacheResolveStrategy implements EddystoneResolveStrategy {

  private final FutureShufflesCache cache;

  EddystoneCacheResolveStrategy(FutureShufflesCache cache) {
    this.cache = cache;
  }

  @Override
  public List<EddystoneFutureUID> resolve(Map<EddystoneUid, EddystoneResolveRequest> requests) throws Exception {
    List<EddystoneUid> toResolve = eddystonesToResolve(requests);
    if (toResolve.isEmpty()) {
      return Collections.emptyList();
    }

    List<EddystoneFutureUID> futureIds = resolveEddystones(toResolve);
    updateRequests(requests, futureIds);
    return futureIds;
  }

  private List<EddystoneUid> eddystonesToResolve(final Map<EddystoneUid, EddystoneResolveRequest> requests) {
    List<EddystoneUid> toResolve = new ArrayList<>();
    for (Map.Entry<EddystoneUid, EddystoneResolveRequest> entry : requests.entrySet()) {
      EddystoneResolveRequest request = entry.getValue();
      if (ResolveRequestStatus.RESOLVED == request.getStatus()) {
        continue;
      }
      toResolve.add(entry.getKey());
    }
    return toResolve;
  }

  private List<EddystoneFutureUID> resolveEddystones(List<EddystoneUid> uids) {
    List<EddystoneFutureUID> futureIds = new ArrayList<>();
    for (EddystoneUid eddystoneUID : uids) {
      ResolvedId resolvedId = cache.get(eddystoneUID.toString());
      if (resolvedId == null || FutureShufflesCache.PHANTOM_ENTRY.equals(resolvedId)) {
        continue;
      }

      EddystoneFutureUID eddystoneFutureId = new EddystoneFutureUID.Builder().futureIds(new ArrayList<EddystoneUid>())
          .uniqueId(resolvedId.getUniqueId())
          .queriedBy(eddystoneUID)
          .resolved(resolvedId.getEddystoneUID())
          .build();
      futureIds.add(eddystoneFutureId);
    }
    return futureIds;
  }

  private void updateRequests(Map<EddystoneUid, EddystoneResolveRequest> requests, List<EddystoneFutureUID> futureIds) {
    for (EddystoneFutureUID id : futureIds) {
      updateRequest(requests, id);
    }
  }

  private void updateRequest(Map<EddystoneUid, EddystoneResolveRequest> requests, EddystoneFutureUID id) {
    EddystoneResolveRequest request = requests.get(id.getQueriedBy());
    request.setResolvedBy(ResolverType.CACHE);
    if (ResolveRequestStatus.IGNORED == request.getStatus()) {
      return;
    }
    request.setStatus(ResolveRequestStatus.RESOLVED);
  }
}
